==> acs_0.25.orig.tar.gz: acs-0.25/src/l_lib.h <==
/*$Id: l_lib.h,v 14.19 1999/08/18 17:17:11 al Exp $ -*- C++ -*-
 */
#ifndef L_LIB_H
#define L_LIB_H
#include "md.h"
/*--------------------------------------------------------------------------*/
	char*	trim(char*);
	int	pmatch(const char*,const char*);
	bool	wmatch(const char*,const char*);
/*--------------------------------------------------------------------------*/
//ftos stuff
	char*	ftos(double,int,int,int);
	void	ftos_set_floor(double);
	int	ftos_set_format(int);
	int	ftos_set_precision(int);
	int	ftos_set_width(int);
enum {			/* formatting bit-fields */
  ftos_DEFAULT = 0,	/* default formatting, with letters */
  ftos_EXP = 1,		/* use 'e' notation, almost like printf */
  ftos_SIGN = 2,	/* always include sign */
  ftos_FILL = 4		/* fill in trailing zeros */
};
/*--------------------------------------------------------------------------*/
// updated forms of old stuff
namespace OS {
  inline void system(const std::string& s){
    ::system(s.c_str());
  }
  inline void chdir(const std::string& s){
    ::chdir(s.c_str());
  }
  inline void remove(const std::string& s){
    ::remove(s.c_str());
  }
  inline bool access_ok(const std::string& file, int mode){
    return (::access(file.c_str(), mode) == 0/*file_ok*/);
  }
  inline std::string getcwd(){
    char buf[BUFLEN+1];
    char* cwd = ::getcwd(buf,BUFLEN);
    {if (cwd){
      return cwd;
    }else{
      untested();
      return "";
    }}
  }
  inline std::string getenv(const std::string& s){
    char* ev = ::getenv(s.c_str());
    {if (ev){
      return ev;
    }else{
      return "";
    }}
  }
};
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
#endif

==> acs-0.28.tar.gz: acs-0.28/src/l_lib.h <==
/*$Id: l_lib.h,v 18.9 2000/08/16 08:11:43 al Exp $ -*- C++ -*-
 */
#ifndef L_LIB_H
#define L_LIB_H
#include "md.h"
/*--------------------------------------------------------------------------*/
	char*	trim(char*);
	int	pmatch(const char*,const char*);
	bool	wmatch(const char*,const char*);
/*--------------------------------------------------------------------------*/
//ftos stuff
	char*	ftos(double,int,int,int);
	void	ftos_set_floor(double);
	int	ftos_set_format(int);
	int	ftos_set_precision(int);
	int	ftos_set_width(int);
enum {			/* formatting bit-fields */
  ftos_DEFAULT = 0,	/* default formatting, with letters */
  ftos_EXP = 1,		/* use 'e' notation, almost like printf */
  ftos_SIGN = 2,	/* always include sign */
  ftos_FILL = 4		/* fill in trailing zeros */
};
/*--------------------------------------------------------------------------*/
// wrappers for type conversion
inline bool wmatch(const std::string& s1,const char* s2){
  return wmatch(s1.c_str(), s2);
}
inline bool wmatch(const std::string& s1,const std::string& s2){
  untested();
  return wmatch(s1.c_str(), s2.c_str());
}
/*--------------------------------------------------------------------------*/
// updated forms of old stuff
namespace OS {
  inline void system(const std::string& s){
    ::system(s.c_str());
  }
  inline void chdir(const std::string& s){
    ::chdir(s.c_str());
  }
  inline void remove(const std::string& s){
    ::remove(s.c_str());
  }
  inline bool access_ok(const std::string& file, int mode){
    return (::access(file.c_str(), mode) == 0/*file_ok*/);
  }
  inline std::string getcwd(){
    char buf[BUFLEN+1];
    char* cwd = ::getcwd(buf,BUFLEN);
    {if (cwd){
      return cwd;
    }else{
      untested();
      return "";
    }}
  }
  inline std::string getenv(const std::string& s){
    char* ev = ::getenv(s.c_str());
    {if (ev){
      return ev;
    }else{
      return "";
    }}
  }
};
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
#endif
